pub enum AxisLocation {
User(OrderedFloat<f64>),
Design(OrderedFloat<f64>),
Normalized(OrderedFloat<f64>),
}Expand description
A location on an axis, in one of three coordinate spaces, as specified in a fea file.
Variants
User(OrderedFloat<f64>)
A position in the user coordinate space
Design(OrderedFloat<f64>)
A position in the design coordinate space
Normalized(OrderedFloat<f64>)
A normalized position