#[non_exhaustive]pub enum FontGlyphOrderError {
ReadError(ReadError),
MissingNames,
BadGlyphOrder(GlyphOrderError),
}Expand description
An error that occurs when extracting a glyph order from a font file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadError(ReadError)
Failed to read font data
MissingNames
Post table is missing glyph names
BadGlyphOrder(GlyphOrderError)
Glyphs were present but not a valid glyph order.