#[non_exhaustive]pub enum UfoGlyphOrderError {
KeyNotSet,
Malformed,
BadGlyphOrder(GlyphOrderError),
}Expand description
An error that occurs when extracting a glyph order from a UFO.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KeyNotSet
Missing ‘public.glyphOrder’ key
Malformed
Glyph order is present, but malformed
BadGlyphOrder(GlyphOrderError)
Glyphs were present but not a valid glyph order.